]> git.ipfire.org Git - thirdparty/git.git/blobdiff - diff.c
pack-write: use hashwrite_be64()
[thirdparty/git.git] / diff.c
diff --git a/diff.c b/diff.c
index a5114fa86468ceff56005ed83fcb10f129dc0fc2..2bb2f8f57e8b7ce5a6d861b7a1d598a7fbaf68e9 100644 (file)
--- a/diff.c
+++ b/diff.c
@@ -482,14 +482,14 @@ int git_diff_basic_config(const char *var, const char *value, void *cb)
 
 static char *quote_two(const char *one, const char *two)
 {
-       int need_one = quote_c_style(one, NULL, NULL, 1);
-       int need_two = quote_c_style(two, NULL, NULL, 1);
+       int need_one = quote_c_style(one, NULL, NULL, CQUOTE_NODQ);
+       int need_two = quote_c_style(two, NULL, NULL, CQUOTE_NODQ);
        struct strbuf res = STRBUF_INIT;
 
        if (need_one + need_two) {
                strbuf_addch(&res, '"');
-               quote_c_style(one, &res, NULL, 1);
-               quote_c_style(two, &res, NULL, 1);
+               quote_c_style(one, &res, NULL, CQUOTE_NODQ);
+               quote_c_style(two, &res, NULL, CQUOTE_NODQ);
                strbuf_addch(&res, '"');
        } else {
                strbuf_addstr(&res, one);
@@ -3663,7 +3663,7 @@ static void builtin_diffstat(const char *name_a, const char *name_b,
 {
        mmfile_t mf1, mf2;
        struct diffstat_file *data;
-       int same_contents;
+       int may_differ;
        int complete_rewrite = 0;
 
        if (!DIFF_PAIR_UNMERGED(p)) {
@@ -3681,12 +3681,14 @@ static void builtin_diffstat(const char *name_a, const char *name_b,
                return;
        }
 
-       same_contents = oideq(&one->oid, &two->oid);
+       /* saves some reads if true, not a guarantee of diff outcome */
+       may_differ = !(one->oid_valid && two->oid_valid &&
+                       oideq(&one->oid, &two->oid));
 
        if (diff_filespec_is_binary(o->repo, one) ||
            diff_filespec_is_binary(o->repo, two)) {
                data->is_binary = 1;
-               if (same_contents) {
+               if (!may_differ) {
                        data->added = 0;
                        data->deleted = 0;
                } else {
@@ -3702,7 +3704,7 @@ static void builtin_diffstat(const char *name_a, const char *name_b,
                data->added = count_lines(two->data, two->size);
        }
 
-       else if (!same_contents) {
+       else if (may_differ) {
                /* Crazy xdl interfaces.. */
                xpparam_t xpp;
                xdemitconf_t xecfg;
@@ -3727,7 +3729,7 @@ static void builtin_diffstat(const char *name_a, const char *name_b,
                                diffstat->files[diffstat->nr - 1];
                        /*
                         * Omit diffstats of modified files where nothing changed.
* Even if !same_contents, this might be the case due to
                         * ignoring whitespace changes, etc.
                         *
                         * But note that we special-case additions, deletions,
@@ -3727,7 +3729,7 @@ static void builtin_diffstat(const char *name_a, const char *name_b,
                        /*
                         * Omit diffstats of modified files where nothing changed.
-                        * Even if !same_contents, this might be the case due to
+                        * Even if may_differ, this might be the case due to
                         * ignoring whitespace changes, etc.
                         *